package com.landray.kmss.sys.attachment.actions;

import com.landray.kmss.web.config.IActionConfig;
import java.util.Map;
import com.landray.kmss.web.config.ForwardConfig;
import com.landray.kmss.util.ResourceUtil;
import net.sf.json.JSONObject;
import com.landray.kmss.sys.attachment.forms.SysAttWaterMarkForm;
import java.io.OutputStream;
import java.io.InputStream;
import com.landray.kmss.sys.attachment.io.IOUtil;
import com.landray.kmss.sys.attachment.util.SysAttViewerUtil;
import com.landray.kmss.web.action.ActionForward;
import javax.servlet.http.HttpServletResponse;
import com.landray.kmss.web.action.ActionForm;
import com.landray.kmss.web.action.ActionMapping;
import com.landray.kmss.common.service.IBaseService;
import javax.servlet.http.HttpServletRequest;
import org.slf4j.LoggerFactory;
import org.slf4j.Logger;
import com.landray.kmss.common.actions.ExtendAction;

public class SysAttWaterMarkAction extends ExtendAction
{
    private Logger logger;
    
    public SysAttWaterMarkAction() {
        this.logger = LoggerFactory.getLogger(SysAttWaterMarkAction.class);
    }
    
    protected IBaseService getServiceImp(final HttpServletRequest request) {
        return null;
    }
    
    public ActionForward getWaterMarkPNG(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        InputStream in = null;
        OutputStream out = null;
        try {
            out = (OutputStream)response.getOutputStream();
            in = SysAttViewerUtil.getWaterMarkPNG(SysAttViewerUtil.getWaterMarkConfigInRequest(request, "get"));
            if (in != null) {
                IOUtil.write(in, out);
            }
            return null;
        }
        catch (final Exception e) {
            this.streamClose(in, out);
            this.logger.info("error", e);
            return null;
        }
        finally {
            this.streamClose(in, out);
        }
    }
    
    private void streamClose(InputStream in, OutputStream out) {
        try {
            if (in != null) {
                in.close();
                in = null;
            }
            if (out != null) {
                out.close();
                out = null;
            }
        }
        catch (final Exception e) {
            this.logger.debug("流关闭错误，错误信息", e);
        }
    }
    
    public ActionForward configWaterMark(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        request.setAttribute("isConfig", (Object)"true");
        final JSONObject waterMarkConfig = SysAttViewerUtil.getWaterMarkConfigInDB(Boolean.valueOf(false));
        final JSONObject waterMarkInfos = SysAttViewerUtil.getWaterMarkInfos(waterMarkConfig, request);
        waterMarkConfig.accumulate("otherInfos", (Object)waterMarkInfos);
        request.setAttribute("waterMarkConfig", (Object)waterMarkConfig.toString());
        final SysAttWaterMarkForm waterMarkForm = (SysAttWaterMarkForm)form;
        this.copyProperties(waterMarkForm, waterMarkConfig);
        request.setAttribute("sysAttWaterMarkForm", (Object)waterMarkForm);
        return mapping.findForward("waterMarkConfig");
    }
    
    private void copyProperties(final SysAttWaterMarkForm waterMarkForm, final JSONObject waterMarkConfig) {
        if (waterMarkConfig.has("showWaterMark")) {
            waterMarkForm.setShowWaterMark(waterMarkConfig.getString("showWaterMark"));
        }
        waterMarkForm.setEnablePC(waterMarkConfig.getString("enablePC"));
        waterMarkForm.setEnableMobile(waterMarkConfig.getString("enableMobile"));
        if (waterMarkConfig.has("markOpacity")) {
            waterMarkForm.setMarkOpacity(waterMarkConfig.getString("markOpacity"));
        }
        if (waterMarkConfig.has("markType")) {
            waterMarkForm.setMarkType(waterMarkConfig.getString("markType"));
        }
        if (waterMarkConfig.has("markWordType")) {
            waterMarkForm.setMarkWordType(waterMarkConfig.getString("markWordType"));
        }
        if (waterMarkConfig.has("markWordVar")) {
            waterMarkForm.setMarkWordVar(waterMarkConfig.getString("markWordVar"));
        }
        if (waterMarkConfig.has("markWordFixed")) {
            waterMarkForm.setMarkWordFixed(waterMarkConfig.getString("markWordFixed"));
        }
        if (waterMarkConfig.has("markRowSpace")) {
            waterMarkForm.setMarkRowSpace(waterMarkConfig.getString("markRowSpace"));
        }
        if (waterMarkConfig.has("markColSpace")) {
            waterMarkForm.setMarkColSpace(waterMarkConfig.getString("markColSpace"));
        }
        if (waterMarkConfig.has("markWordFontFamily")) {
            waterMarkForm.setMarkWordFontFamily(waterMarkConfig.getString("markWordFontFamily"));
        }
        if (waterMarkConfig.has("markWordFontColor")) {
            waterMarkForm.setMarkWordFontColor(waterMarkConfig.getString("markWordFontColor"));
        }
        if (waterMarkConfig.has("markWordFontSize")) {
            waterMarkForm.setMarkWordFontSize(waterMarkConfig.getString("markWordFontSize"));
        }
        if (waterMarkConfig.has("markRotateType")) {
            waterMarkForm.setMarkRotateType(waterMarkConfig.getString("markRotateType"));
        }
        if (waterMarkConfig.has("markRotateAngel")) {
            waterMarkForm.setMarkRotateAngel(waterMarkConfig.getString("markRotateAngel"));
        }
        if (waterMarkConfig.has("markPicFileName")) {
            waterMarkForm.setMarkPicFileName(waterMarkConfig.getString("markPicFileName"));
        }
    }
    
    public ActionForward saveWaterMark(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        final SysAttWaterMarkForm waterMarkForm = (SysAttWaterMarkForm)form;
        SysAttViewerUtil.saveWaterMarkConfig(waterMarkForm);
        return this.configWaterMark(mapping, form, request, response);
    }
    
    public ActionForward setWaterMarkInfos(final ActionMapping mapping, final ActionForm form, final HttpServletRequest request, final HttpServletResponse response) throws Exception {
        try {
            final JSONObject rtnJson = SysAttViewerUtil.getWaterMarkConfigInRequest(request, "post");
            final JSONObject waterMarkInfos = SysAttViewerUtil.getWaterMarkInfos(rtnJson, request);
            rtnJson.accumulate("otherInfos", (Object)waterMarkInfos);
            request.setAttribute("lui-source", (Object)rtnJson);
        }
        catch (final Exception ex) {
            request.setAttribute("lui-source", (Object)new JSONObject().element("msg", (Object)ResourceUtil.getString("return.optFailure")));
            return this.getActionForward("lui-failure", mapping, form, request, response);
        }
        return this.getActionForward("lui-source", mapping, form, request, response);
    }
}
